@@ -4,8 +4,6 @@ available_on_bioc <- function(name, repos = NULL, ...) {
   if (is.null(repos)) {
     if (requireNamespace("BiocManager", quietly = TRUE)) {
       repos <- BiocManager::repositories()
-    } else if (requireNamespace("BiocInstaller", quietly = TRUE)) {
-      repos <- BiocInstaller::biocinstallRepos()
     } else {
       # Search on latest bioc release
       repos <- c(
@@ -15,9 +13,7 @@ available_on_bioc <- function(name, repos = NULL, ...) {
     }
   }
   bioc_names <- rownames(available_packages(repos = repos, ...))
-
   on_bioc <- tolower(name) %in% tolower(bioc_names)
-
   structure(!on_bioc, class = "available_bioc")
 }
 
