@@ -1,15 +1,9 @@
 #' get urban dictionary definitions and tags
 #'
 #' @param name Name of package to search
+#' @note Urban Dictionary can contain potentially offensive results
 #' @export
-get_urban_data<- function(name) {
-  if (interactive()) {
-    cat("Urban Dictionary can contain potentially offensive results,\n  should they be included? [Y]es / [N]o:\n")
-    result <- tryCatch(scan("", what = "character", quiet = TRUE, nlines = 1), error = function(x) "N")
-    if (!identical(toupper(result), "Y")) {
-      return(NULL)
-    }
-  }
+get_urban_data <- function(name) {
   term <- tryCatch(as.data.frame(udapi::get_term(name)),
                    error = function(e) e)
   tags <- tryCatch(udapi::get_tags(name)$tags, error = function(e) e)
